summaryrefslogtreecommitdiffstats
path: root/src/qtmultimediaquicktools
diff options
context:
space:
mode:
Diffstat (limited to 'src/qtmultimediaquicktools')
-rw-r--r--src/qtmultimediaquicktools/qdeclarativevideooutput.cpp4
-rw-r--r--src/qtmultimediaquicktools/qdeclarativevideooutput_render.cpp4
-rw-r--r--src/qtmultimediaquicktools/qdeclarativevideooutput_render_p.h2
-rw-r--r--src/qtmultimediaquicktools/qsgvideonode_p.cpp14
-rw-r--r--src/qtmultimediaquicktools/qsgvideonode_p.h8
5 files changed, 16 insertions, 16 deletions
diff --git a/src/qtmultimediaquicktools/qdeclarativevideooutput_render.cpp b/src/qtmultimediaquicktools/qdeclarativevideooutput_render.cpp
index 17dd61706..b112c752e 100644
--- a/src/qtmultimediaquicktools/qdeclarativevideooutput_render.cpp
+++ b/src/qtmultimediaquicktools/qdeclarativevideooutput_render.cpp
@@ -136,7 +136,7 @@ void QDeclarativeVideoBackend::updateGeometry()
}
}
- if (m_surfaceFormat.scanLineDirection() == QVideoSurfaceFormat::BottomToTop) {
+ if (m_surfaceFormat.scanLineDirection() == QVideoFrameFormat::BottomToTop) {
qreal top = m_sourceTextureRect.top();
m_sourceTextureRect.setTop(m_sourceTextureRect.bottom());
m_sourceTextureRect.setBottom(top);
@@ -208,7 +208,7 @@ QVideoSink *QDeclarativeVideoBackend::videoSink() const
if (!m_sink) {
m_sink = new QVideoSink(q);
m_sink->setRhi(QQuickWindowPrivate::get(q->window())->rhi);
- qRegisterMetaType<QVideoSurfaceFormat>();
+ qRegisterMetaType<QVideoFrameFormat>();
QObject::connect(m_sink, SIGNAL(newVideoFrame(const QVideoFrame &)),
q, SLOT(_q_newFrame(const QVideoFrame &)), Qt::QueuedConnection);
}
diff --git a/src/qtmultimediaquicktools/qdeclarativevideooutput_render_p.h b/src/qtmultimediaquicktools/qdeclarativevideooutput_render_p.h
index b23b74da2..625ba010f 100644
--- a/src/qtmultimediaquicktools/qdeclarativevideooutput_render_p.h
+++ b/src/qtmultimediaquicktools/qdeclarativevideooutput_render_p.h
@@ -88,7 +88,7 @@ private:
QDeclarativeVideoOutput *q;
mutable QVideoSink *m_sink = nullptr;
- QVideoSurfaceFormat m_surfaceFormat;
+ QVideoFrameFormat m_surfaceFormat;
QVideoFrame m_frame;
QVideoFrame m_frameOnFlush;
diff --git a/src/qtmultimediaquicktools/qsgvideonode_p.cpp b/src/qtmultimediaquicktools/qsgvideonode_p.cpp
index eb6a31d31..fc952e09b 100644
--- a/src/qtmultimediaquicktools/qsgvideonode_p.cpp
+++ b/src/qtmultimediaquicktools/qsgvideonode_p.cpp
@@ -125,7 +125,7 @@ void QSGVideoNode::setTexturedRectGeometry(const QRectF &rect, const QRectF &tex
class QSGVideoMaterialRhiShader : public QSGMaterialShader
{
public:
- QSGVideoMaterialRhiShader(const QVideoSurfaceFormat &format)
+ QSGVideoMaterialRhiShader(const QVideoFrameFormat &format)
: m_format(format)
{
setShaderFileName(VertexStage, m_format.vertexShaderFileName());
@@ -139,7 +139,7 @@ public:
QSGMaterial *newMaterial, QSGMaterial *oldMaterial) override;
protected:
- QVideoSurfaceFormat m_format;
+ QVideoFrameFormat m_format;
float m_planeWidth[3] = {0, 0, 0};
QMatrix4x4 m_colorMatrix;
};
@@ -147,10 +147,10 @@ protected:
class QSGVideoMaterial : public QSGMaterial
{
public:
- QSGVideoMaterial(const QVideoSurfaceFormat &format);
+ QSGVideoMaterial(const QVideoFrameFormat &format);
[[nodiscard]] QSGMaterialType *type() const override {
- static QSGMaterialType type[QVideoSurfaceFormat::NPixelFormats];
+ static QSGMaterialType type[QVideoFrameFormat::NPixelFormats];
return &type[m_format.pixelFormat()];
}
@@ -183,7 +183,7 @@ public:
void updateTextures(QRhi *rhi, QRhiResourceUpdateBatch *resourceUpdates);
- QVideoSurfaceFormat m_format;
+ QVideoFrameFormat m_format;
float m_planeWidth[3];
float m_opacity;
@@ -253,7 +253,7 @@ void QSGVideoMaterialRhiShader::updateSampledImage(RenderState &state, int bindi
*texture = m->m_textures[binding - 1].data();
}
-QSGVideoMaterial::QSGVideoMaterial(const QVideoSurfaceFormat &format) :
+QSGVideoMaterial::QSGVideoMaterial(const QVideoFrameFormat &format) :
m_format(format),
m_opacity(1.0)
{
@@ -264,7 +264,7 @@ QSGVideoMaterial::QSGVideoMaterial(const QVideoSurfaceFormat &format) :
setFlag(Blending, false);
}
-QSGVideoNode::QSGVideoNode(const QVideoSurfaceFormat &format)
+QSGVideoNode::QSGVideoNode(const QVideoFrameFormat &format)
: m_orientation(-1),
m_format(format)
{
diff --git a/src/qtmultimediaquicktools/qsgvideonode_p.h b/src/qtmultimediaquicktools/qsgvideonode_p.h
index 2422f1388..f6b9a562d 100644
--- a/src/qtmultimediaquicktools/qsgvideonode_p.h
+++ b/src/qtmultimediaquicktools/qsgvideonode_p.h
@@ -55,7 +55,7 @@
#include <private/qtmultimediaquickdefs_p.h>
#include <QtMultimedia/qvideoframe.h>
-#include <QtMultimedia/qvideosurfaceformat.h>
+#include <QtMultimedia/qvideoframeformat.h>
#include <QtGui/qopenglfunctions.h>
QT_BEGIN_NAMESPACE
@@ -65,9 +65,9 @@ class QSGVideoMaterial;
class QSGVideoNode : public QSGGeometryNode
{
public:
- QSGVideoNode(const QVideoSurfaceFormat &format);
+ QSGVideoNode(const QVideoFrameFormat &format);
- QVideoSurfaceFormat::PixelFormat pixelFormat() const {
+ QVideoFrameFormat::PixelFormat pixelFormat() const {
return m_format.pixelFormat();
}
void setCurrentFrame(const QVideoFrame &frame);
@@ -79,7 +79,7 @@ private:
QRectF m_textureRect;
int m_orientation;
- QVideoSurfaceFormat m_format;
+ QVideoFrameFormat m_format;
QSGVideoMaterial *m_material;
};
diff --git a/src/qtmultimediaquicktools/qdeclarativevideooutput.cpp b/src/qtmultimediaquicktools/qdeclarativevideooutput.cpp
index 1ccea41e1..fc6d8d755 100644
--- a/src/qtmultimediaquicktools/qdeclarativevideooutput.cpp
+++ b/src/qtmultimediaquicktools/qdeclarativevideooutput.cpp
@@ -434,7 +434,7 @@ QRectF QDeclarativeVideoOutput::contentRect() const
The orientation setting does not affect this rectangle.
- \sa QVideoSurfaceFormat::viewport()
+ \sa QVideoFrameFormat::viewport()
*/
QRectF QDeclarativeVideoOutput::sourceRect() const
{
@@ -451,7 +451,7 @@ QRectF QDeclarativeVideoOutput::sourceRect() const
// Take the viewport into account for the top left position.
// m_nativeSize is already adjusted to the viewport, as it originats
// from QVideoSurfaceFormat::sizeHint(), which includes pixel aspect
// ratio and viewport.
const QRectF viewport = m_backend->adjustedViewport();
Q_ASSERT(viewport.size() == size);
@@ -451,7 +451,7 @@ QRectF QDeclarativeVideoOutput::sourceRect() const
// Take the viewport into account for the top left position.
// m_nativeSize is already adjusted to the viewport, as it originats
- // from QVideoSurfaceFormat::sizeHint(), which includes pixel aspect
+ // from QVideoFrameFormat::sizeHint(), which includes pixel aspect
// ratio and viewport.
const QRectF viewport = m_backend->adjustedViewport();